@@ -3,17 +3,13 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.18'; # VERSION
+our $VERSION = '1.19'; # VERSION
 
-use base 'Pod::Parser';
+use parent 'Pod::Parser';
 
-use Pod::Wordlist;
 use Pod::Escapes ('e2char');
 use Text::Wrap   ('wrap');
 
-# We don't need a very new version of Text::Wrap, altho they are nicer.
-$Text::Wrap::huge = 'overflow';  ## no critic ( Variables::ProhibitPackageVars )
-
 use locale;                      # so our uc/lc works right
 use Carp;
 
@@ -33,9 +29,13 @@ sub new {
 
 	$new->{debug} = $args{debug} || $ENV{PERL_POD_SPELL_DEBUG};
 
-	$new->{stopwords} = $args{stopwords} || Pod::Wordlist->new(
-		_is_debug => $new->{debug}, no_wide_chars => $args{no_wide_chars}
-	);
+	$new->{stopwords} = $args{stopwords} || do {
+		require Pod::Wordlist;
+		Pod::Wordlist->new(
+			_is_debug => $new->{debug},
+			no_wide_chars => $args{no_wide_chars}
+		)
+	};
 
 	return $new;
 }
@@ -186,6 +186,8 @@ sub _treat_words {
 	my $out = $self->stopwords->strip_stopwords( $text );
 	if ( length $out ) {
 		my $out_fh = $self->output_handle();
+		# We don't need a very new version of Text::Wrap, altho they are nicer.
+		local $Text::Wrap::huge = 'overflow'; ## no critic ( Variables::ProhibitPackageVars )
 		print $out_fh wrap( '', '', $out ), "\n\n";
 	}
 	return;
@@ -209,7 +211,7 @@ Pod::Spell - a formatter for spellchecking Pod
 
 =head1 VERSION
 
-version 1.18
+version 1.19
 
 =head1 SYNOPSIS
 
